CResDdsHeader

Struct CResDdsHeader 

pub struct CResDdsHeader {
    pub width: u32,
    pub height: u32,
    pub bytes_per_pixel_code: u8,
    pub reserved_gap_bytes: [u8; 3],
    pub base_level_data_size: u32,
    pub alpha_mean: f32,
}
Parsed CResDDS prefix metadata header.

Fields

width: u32

Base width in pixels.

height: u32

Base height in pixels.

bytes_per_pixel_code: u8

Prefix bytes-per-pixel code as stored on disk.

Canonically observed values:

  • 3 => DXT1 payload sizing
  • 4 => 16-byte block-family payload sizing (modeled as DXT5 here)
reserved_gap_bytes: [u8; 3]

Reserved bytes from offsets +0x09..+0x0B.

Native K1 attribute-read paths do not consume these bytes, but they are retained for loss-aware inspection/debugging.

base_level_data_size: u32

Base-level payload size field from header.

alpha_mean: f32

Prefix alpha-mean metadata float (+0x10).

Native K1 attribute-read paths surface this value directly as part of the compressed-texture attribute tuple and route it into texture alpha-mean handling.