pub enum GffPathSegment {
Field(GffLabel),
Index(usize),
}Expand description
One step of a GffPath.
Variants
Field(GffLabel)
Name a field of the struct currently in hand.
Index(usize)
Take an element of the list currently in hand.