pub struct MdlWriteResult {
pub mdl_bytes: Vec<u8>,
pub mdx_bytes: Vec<u8>,
}Expand description
Result of writing an MDL model with its companion MDX vertex data.
The MDL and MDX files are always written as a pair - the MDL contains header references to vertex data stored in the MDX buffer.
Fields
mdl_bytes: Vec<u8>The MDL binary data.
mdx_bytes: Vec<u8>The MDX vertex data.