pub fn read_rim_with_options<R: Read>(
reader: &mut R,
options: RimReadOptions,
) -> Result<Rim, RimBinaryError>Expand description
Reads a RIM archive from a reader with explicit read options.
Errors
RimBinaryError::Io when the stream will not read to end, and whatever
read_rim_from_bytes_with_options reports for the bytes it collected.