write_ssf

Function write_ssf 

pub fn write_ssf<W: Write>(
    writer: &mut W,
    ssf: &Ssf,
) -> Result<(), SsfBinaryError>
Writes an SSF file to a writer.

Errors

SsfBinaryError::InvalidHeader when the sound-table offset would overlap the header, which is checked before anything is written, and SsfBinaryError::Io when the writer fails. A partial file may already have been written in the second case.