pub enum TwoDaBinaryError {
Io(Error),
InvalidMagic([u8; 4]),
InvalidVersion([u8; 4]),
InvalidHeader(String),
InvalidTable(String),
ValueOverflow(&'static str),
TextEncoding {
context: String,
source: EncodeTextError,
},
TextDecoding {
context: String,
source: DecodeTextError,
},
}Expand description
Errors produced while parsing or serializing binary 2DA data.
Variants
Io(Error)
I/O read/write failure.
InvalidMagic([u8; 4])
Header magic does not match 2DA .
InvalidVersion([u8; 4])
Header version is unsupported.
InvalidHeader(String)
Header/body layout is invalid or truncated.
InvalidTable(String)
In-memory table content is structurally invalid for writing.
ValueOverflow(&'static str)
Value cannot fit the target on-disk integer width.
TextEncoding
Text cannot be represented losslessly as the configured target encoding.
Fields

source: EncodeTextErrorSource encoding error with exact character location.
TextDecoding
Text bytes cannot be decoded losslessly using the configured encoding.
Fields

source: DecodeTextErrorSource decoding error with byte position details.