read_txi_with_options

Function read_txi_with_options 

pub fn read_txi_with_options<R: Read>(
    reader: &mut R,
    options: TxiReadOptions,
) -> Result<Txi, TxiError>
Reads TXI data from a reader with explicit parse options.

Errors

TxiError::Io when the stream will not read to end, and whatever read_txi_from_bytes_with_options reports for the bytes it collected.