pub fn read_vis<R: Read>(reader: &mut R) -> Result<Vis, VisError>Expand description
Reads a VIS graph from a reader.
Errors
VisError::Io when the stream will not read to end, and whatever
read_vis_from_bytes reports for the bytes it collected.
pub fn read_vis<R: Read>(reader: &mut R) -> Result<Vis, VisError>Reads a VIS graph from a reader.
VisError::Io when the stream will not read to end, and whatever
read_vis_from_bytes reports for the bytes it collected.