pub fn read_wav<R: Read>(reader: &mut R) -> Result<Wav, WavError>Expand description
Reads WAV data from a reader.
Errors
WavError::Io when the stream will not read to end, and whatever
read_wav_from_bytes reports for the bytes it collected.
pub fn read_wav<R: Read>(reader: &mut R) -> Result<Wav, WavError>Reads WAV data from a reader.
WavError::Io when the stream will not read to end, and whatever
read_wav_from_bytes reports for the bytes it collected.