pub enum PcmError {
UnsupportedEncoding(Option<WavEncoding>),
UnsupportedBitDepth(u16),
MisalignedData(usize, usize),
}Expand description
Errors that can occur during PCM decoding.
Variants
UnsupportedEncoding(Option<WavEncoding>)
The WAV data is not in a supported PCM format.
UnsupportedBitDepth(u16)
The bit depth is not supported for the given encoding.
MisalignedData(usize, usize)
The data length is not aligned with the block size.