pub fn read_erf_with_options<R: Read>(
reader: &mut R,
options: ErfReadOptions,
) -> Result<Erf, ErfBinaryError>Expand description
Reads an ERF-family archive from a reader with explicit read options.
Errors
ErfBinaryError::Io when the stream will not read to end, and whatever
read_erf_from_bytes_with_options reports for the bytes it collected.