pub fn read_erf_with_options<R: Read>(
reader: &mut R,
options: ErfReadOptions,
) -> Result<Erf, ErfBinaryError>Expand description
Reads an ERF-family archive from a reader with explicit read options.
pub fn read_erf_with_options<R: Read>(
reader: &mut R,
options: ErfReadOptions,
) -> Result<Erf, ErfBinaryError>Reads an ERF-family archive from a reader with explicit read options.