pub struct GffLabel { /* private fields */ }Expand description
Canonicalized GFF field label.
GFF labels are identifiers with a maximum length of 16 characters. This type stores
the exact casing of the label as an inline fixed-size buffer, making it Copy and
zero-allocation.
Valid characters are restricted to ASCII alphanumerics, underscores, and spaces ([A-Za-z0-9_ ]).
Implementations
Sourceimpl GffLabel
impl GffLabel