pub struct LipShapeCode(/* private fields */);Expand description
Lossless LIP shape code wrapper.
This preserves unknown IDs during parse/write roundtrips while still exposing known viseme values where possible.
Implementations
Sourceimpl LipShapeCode
impl LipShapeCode
Sourcepub const fn from_raw_id(raw_id: u8) -> Self
pub const fn from_raw_id(raw_id: u8) -> Self
Creates a shape code from raw on-disk value.
Sourcepub fn known_shape(self) -> Option<LipShape>
pub fn known_shape(self) -> Option<LipShape>
Returns the known shape when this code maps to one.