pub fn read_rim_with_options<R: Read>(
reader: &mut R,
options: RimReadOptions,
) -> Result<Rim, RimBinaryError>Expand description
Reads a RIM archive from a reader with explicit read options.
pub fn read_rim_with_options<R: Read>(
reader: &mut R,
options: RimReadOptions,
) -> Result<Rim, RimBinaryError>Reads a RIM archive from a reader with explicit read options.