pub struct Tpc {
pub header: TpcHeader,
pub payload: Vec<u8>,
pub txi_footer: Vec<u8>,
}Expand description
In-memory TPC container.
Fields
header: TpcHeaderParsed header fields.
payload: Vec<u8>Raw texture payload bytes between header and optional TXI footer.
Raw trailing TXI footer bytes.
Implementations
Sourceimpl Tpc
impl Tpc
Sourcepub fn new(header: TpcHeader, payload: Vec<u8>, txi_footer: Vec<u8>) -> Self
pub fn new(header: TpcHeader, payload: Vec<u8>, txi_footer: Vec<u8>) -> Self
Creates a TPC object from explicit parts.
Sourcepub fn known_pixel_format(&self) -> Option<TpcHeaderPixelFormat>
pub fn known_pixel_format(&self) -> Option<TpcHeaderPixelFormat>
Returns known pixel format if this header code is currently supported.
Sourcepub fn is_cube_map(&self) -> bool
pub fn is_cube_map(&self) -> bool
Returns true when this container encodes a cubemap payload shape.
Sourcepub fn txi_text_strict(&self) -> Result<String, DecodeTextError>
pub fn txi_text_strict(&self) -> Result<String, DecodeTextError>
Decodes the trailing TXI footer as strict Windows-1252 text.
Sourcepub fn set_txi_text(&mut self, text: &str) -> Result<(), EncodeTextError>
pub fn set_txi_text(&mut self, text: &str) -> Result<(), EncodeTextError>
Replaces trailing TXI footer bytes from Windows-1252 text.